@@ -122,7 +122,7 @@ t.test('config list overrides', t => {
 
   config(['list'], (err) => {
     t.ifError(err, 'npm config list')
-    t.matchSnapshot(result, 'should list overriden configs')
+    t.matchSnapshot(result, 'should list overridden configs')
   })
 })
 
@@ -212,6 +212,33 @@ t.test('config delete key', t => {
   })
 })
 
+t.test('config delete multiple key', t => {
+  t.plan(6)
+
+  const expect = [
+    'foo',
+    'bar',
+  ]
+
+  npm.config.delete = (key, where) => {
+    t.equal(key, expect.shift(), 'should delete expected keyword')
+    t.equal(where, 'user', 'should delete key from user config by default')
+  }
+
+  npm.config.save = where => {
+    t.equal(where, 'user', 'should save user config post-delete')
+  }
+
+  config(['delete', 'foo', 'bar'], (err) => {
+    t.ifError(err, 'npm config delete keys')
+  })
+
+  t.teardown(() => {
+    delete npm.config.delete
+    delete npm.config.save
+  })
+})
+
 t.test('config delete key --global', t => {
   t.plan(4)
 
@@ -293,12 +320,43 @@ t.test('config set key=val', t => {
   })
 })
 
+t.test('config set multiple keys', t => {
+  t.plan(11)
+
+  const expect = [
+    ['foo', 'bar'],
+    ['bar', 'baz'],
+    ['asdf', ''],
+  ]
+  const args = ['foo', 'bar', 'bar=baz', 'asdf']
+
+  npm.config.set = (key, val, where) => {
+    const [expectKey, expectVal] = expect.shift()
+    t.equal(key, expectKey, 'should set expected key to user config')
+    t.equal(val, expectVal, 'should set expected value to user config')
+    t.equal(where, 'user', 'should set key/val in user config by default')
+  }
+
+  npm.config.save = where => {
+    t.equal(where, 'user', 'should save user config')
+  }
+
+  config(['set', ...args], (err) => {
+    t.ifError(err, 'npm config set key')
+  })
+
+  t.teardown(() => {
+    delete npm.config.set
+    delete npm.config.save
+  })
+})
+
 t.test('config set key to empty value', t => {
   t.plan(5)
 
   npm.config.set = (key, val, where) => {
     t.equal(key, 'foo', 'should set expected key to user config')
-    t.equal(val, '', 'should set empty value to user config')
+    t.equal(val, '', 'should set "" to user config')
     t.equal(where, 'user', 'should set key/val in user config by default')
   }
 
@@ -403,6 +461,36 @@ t.test('config get key', t => {
   })
 })
 
+t.test('config get multiple keys', t => {
+  t.plan(4)
+
+  const expect = [
+    'foo',
+    'bar',
+  ]
+
+  const npmConfigGet = npm.config.get
+  npm.config.get = (key) => {
+    t.equal(key, expect.shift(), 'should use expected key')
+    return 'asdf'
+  }
+
+  npm.config.save = where => {
+    throw new Error('should not save')
+  }
+
+  config(['get', 'foo', 'bar'], (err) => {
+    t.ifError(err, 'npm config get multiple keys')
+    t.equal(result, 'foo=asdf\nbar=asdf')
+  })
+
+  t.teardown(() => {
+    result = ''
+    npm.config.get = npmConfigGet
+    delete npm.config.save
+  })
+})
+
 t.test('config get private key', t => {
   config(['get', '//private-reg.npmjs.org/:_authThoken'], (err) => {
     t.match(
